==> ejc-assistrmat-api-3.0.0-20220331.102040-35-sources.jar: com/ejianc/business/assist/rmat/vo/RestituteScrapVO.java <==
package com.ejianc.business.assist.rmat.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 退赔单报废清单明细
 * 
 * @author generator
 * 
 */
public class RestituteScrapVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long materialId; // 物料主键
    private String materialName; // 物料名称
    private Long materialTypeId; // 物料分类
    private String materialTypeName; // 物料分类名称
    private String materialCode; // 物料编码
    private String spec; // 规格型号
    private String unitName; // 计量单位
    private BigDecimal damageNum; // 报废数量
    private BigDecimal mnyTax; // 本次损坏赔偿金额
    private BigDecimal sumMny; // 损坏赔偿金额计算
    private String damageName; // 损坏赔偿名称
    private String damageUnit; // 损坏赔偿单位
    private BigDecimal damageTaxPrice; // 损坏赔偿单价
    private BigDecimal damagePrice; // 损坏赔偿单价
    private BigDecimal taxRate; // 税率
    private BigDecimal mny; // 本次损坏赔偿金额(无税)
    private BigDecimal taxMny; // 本次损坏赔偿金额
    private String memo; // 备注
    private Long restituteId; // 退赔单主键
    private Long unitId; // 单位主键
    private BigDecimal tax; // 损坏赔偿税额
    private BigDecimal sumTaxMny; // 损坏赔偿金额计算(含税)
    

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getDamageNum() {
        return damageNum;
    }

    public void setDamageNum(BigDecimal damageNum) {
        this.damageNum = damageNum;
    }
    public BigDecimal getMnyTax() {
        return mnyTax;
    }

    public void setMnyTax(BigDecimal mnyTax) {
        this.mnyTax = mnyTax;
    }
    public BigDecimal getSumMny() {
        return sumMny;
    }

    public void setSumMny(BigDecimal sumMny) {
        this.sumMny = sumMny;
    }
    public String getDamageName() {
        return damageName;
    }

    public void setDamageName(String damageName) {
        this.damageName = damageName;
    }
    public String getDamageUnit() {
        return damageUnit;
    }

    public void setDamageUnit(String damageUnit) {
        this.damageUnit = damageUnit;
    }
    public BigDecimal getDamagePrice() {
        return damagePrice;
    }

    public void setDamagePrice(BigDecimal damagePrice) {
        this.damagePrice = damagePrice;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getRestituteId() {
        return restituteId;
    }

    public void setRestituteId(Long restituteId) {
        this.restituteId = restituteId;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public BigDecimal getSumTaxMny() {
        return sumTaxMny;
    }

    public void setSumTaxMny(BigDecimal sumTaxMny) {
        this.sumTaxMny = sumTaxMny;
    }

    public BigDecimal getDamageTaxPrice() {
        return damageTaxPrice;
    }

    public void setDamageTaxPrice(BigDecimal damageTaxPrice) {
        this.damageTaxPrice = damageTaxPrice;
    }
}

==> ejc-assistrmat-api-3.0.0-20220526.074338-121-sources.jar: com/ejianc/business/assist/rmat/vo/RestituteScrapVO.java <==
package com.ejianc.business.assist.rmat.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 退赔单报废清单明细
 * 
 * @author generator
 * 
 */
public class RestituteScrapVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long materialId; // 物料主键
    private String materialName; // 物料名称
    private Long materialTypeId; // 物料分类
    private String materialTypeName; // 物料分类名称
    private String materialCode; // 物料编码
    private String spec; // 规格型号
    private String unitName; // 计量单位
    private BigDecimal damageNum; // 报废数量
    private BigDecimal mnyTax; // 本次损坏赔偿金额
    private BigDecimal sumMny; // 损坏赔偿金额计算
    private String damageName; // 损坏赔偿名称
    private String damageUnit; // 损坏赔偿单位
    private BigDecimal damageTaxPrice; // 损坏赔偿单价
    private BigDecimal damagePrice; // 损坏赔偿单价
    private BigDecimal taxRate; // 税率
    private BigDecimal mny; // 本次损坏赔偿金额(无税)
    private BigDecimal taxMny; // 本次损坏赔偿金额
    private String memo; // 备注
    private Long restituteId; // 退赔单主键
    private Long unitId; // 单位主键
    private BigDecimal tax; // 损坏赔偿税额
    private BigDecimal sumTaxMny; // 损坏赔偿金额计算(含税)
    

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getDamageNum() {
        return damageNum;
    }

    public void setDamageNum(BigDecimal damageNum) {
        this.damageNum = damageNum;
    }
    public BigDecimal getMnyTax() {
        return mnyTax;
    }

    public void setMnyTax(BigDecimal mnyTax) {
        this.mnyTax = mnyTax;
    }
    public BigDecimal getSumMny() {
        return sumMny;
    }

    public void setSumMny(BigDecimal sumMny) {
        this.sumMny = sumMny;
    }
    public String getDamageName() {
        return damageName;
    }

    public void setDamageName(String damageName) {
        this.damageName = damageName;
    }
    public String getDamageUnit() {
        return damageUnit;
    }

    public void setDamageUnit(String damageUnit) {
        this.damageUnit = damageUnit;
    }
    public BigDecimal getDamagePrice() {
        return damagePrice;
    }

    public void setDamagePrice(BigDecimal damagePrice) {
        this.damagePrice = damagePrice;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getRestituteId() {
        return restituteId;
    }

    public void setRestituteId(Long restituteId) {
        this.restituteId = restituteId;
    }
    @ReferSerialTransfer(referCode = "share-unit")
    public Long getUnitId() {
        return unitId;
    }
    @ReferDeserialTransfer
    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public BigDecimal getSumTaxMny() {
        return sumTaxMny;
    }

    public void setSumTaxMny(BigDecimal sumTaxMny) {
        this.sumTaxMny = sumTaxMny;
    }

    public BigDecimal getDamageTaxPrice() {
        return damageTaxPrice;
    }

    public void setDamageTaxPrice(BigDecimal damageTaxPrice) {
        this.damageTaxPrice = damageTaxPrice;
    }
}
